@@ -416,15 +416,15 @@ class SignacProjectCrawler(RegexFileCrawler):
 
 
 class MasterCrawler(BaseCrawler):
-    """Compiles a master index from indeces defined in access modules.
+    """Compiles a master index from indexes defined in access modules.
 
     An instance of this crawler will search the data space for access
     modules, which by default are named ``signac_access.py``. Once such
     a file is found, the crawler will import the module and try to execute
     two special functions given that they are defined within the module's
-    global namespace: ``get_indeces()`` and ``get_crawlers()``.
+    global namespace: ``get_indexes()`` and ``get_crawlers()``.
 
-    The ``get_indeces()`` is assumed to yield one or multiple index generator
+    The ``get_indexes()`` is assumed to yield one or multiple index generator
     functions, while the ``get_crawlers()`` function is assumed to yield
     one or more crawler instances.
 
@@ -434,13 +434,13 @@ class MasterCrawler(BaseCrawler):
 
         import signac
 
-        def get_indeces(root):
+        def get_indexes(root):
             yield signac.index_files(root, '.*\.txt')
 
         def get_crawlers(root):
             yield MyCrawler(root)
 
-    In case that the master crawler has tags, the ``get_indeces()`` function
+    In case that the master crawler has tags, the ``get_indexes()`` function
     will always be ignored while crawlers yielded from the ``get_crawlers()``
     function will only be executed in case that they match at least one
     of the tags.
@@ -452,18 +452,18 @@ class MasterCrawler(BaseCrawler):
 
         import signac
 
-        def get_indeces(root):
+        def get_indexes(root):
             yield signac.get_project(root).index()
 
-    Tags for indexes yielded from the `get_indeces()` function can be specified
+    Tags for indexes yielded from the `get_indexes()` function can be specified
     by assigning them directly to the function:
 
     .. code-block:: python
 
-        def get_indeces(root):
+        def get_indexes(root):
             yield signac.get_project(root).index()
 
-        get_indeces.tags = {'foo'}
+        get_indexes.tags = {'foo'}
 
 
     :param root: The path to the root directory to crawl through.
@@ -511,9 +511,9 @@ class MasterCrawler(BaseCrawler):
             for doc in get_project(root=dirpath).index():
                 yield doc
 
-        if hasattr(module, 'get_indeces'):
-            if _check_tags(getattr(module.get_indeces, 'tags', None)):
-                for index in module.get_indeces(dirpath):
+        if hasattr(module, 'get_indexes'):
+            if _check_tags(getattr(module.get_indexes, 'tags', None)):
+                for index in module.get_indexes(dirpath):
                     for doc in index:
                         yield doc
 
@@ -882,8 +882,8 @@ def index(root='.', tags=None, depth=0, **kwargs):
 
     A master index is compiled from other indexes by searching
     for modules named ``signac_access.py`` and compiling all
-    indeces which are yielded from a function ``get_indeces(root)``
-    defined within that module as well as the indeces generated by
+    indexes which are yielded from a function ``get_indexes(root)``
+    defined within that module as well as the indexes generated by
     crawlers yielded from a function ``get_crawlers(root)`` defined
     within that module.
 
@@ -893,7 +893,7 @@ def index(root='.', tags=None, depth=0, **kwargs):
 
         import signac
 
-        def get_indeces(root):
+        def get_indexes(root):
             yield signac.index_files(root, '.*\.txt')
 
     Internally, this function constructs an instance of
